jet

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 8, 2018 License: MIT Imports: 7 Imported by: 0

README

jet

GoDoc Build Status Go Report Status Coverage Status

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RunServer

func RunServer(ctx context.Context, s *http.Server, l net.Listener) (err error)

RunServer starts the server synchronously with the given context, server and listener. The server can be gracefully shut down using the given context.

RunServer returns nil in case of ErrServerClosed.

func StackFunctions

func StackFunctions(ctx context.Context, jobs ...func(context.Context) error) (err error)

StackFunctions allows to specify the stop/exit order for the given functions and the ability to cancel them with the single given context. Notes: - Each function starts in it's own goroutine. - The given context cancels the last function (top of the stack).

Types

This section is empty.

Jump to