Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RunServer ¶
RunServer starts the server synchronously with the given context, server and listener. The server can be gracefully shut down using the given context.
RunServer returns nil in case of ErrServerClosed.
func StackFunctions ¶
StackFunctions allows to specify the stop/exit order for the given functions and the ability to cancel them with the single given context. Notes: - Each function starts in it's own goroutine. - The given context cancels the last function (top of the stack).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.